@@ -4,7 +4,7 @@ import os
 import sys
 
 
-def main(*args, **kwargs):
+def main(*args):
     """Run administrative tasks."""
     os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'OpenHubAPI.settings')
     try:
